@@ -4,7 +4,7 @@ use Moo;
 use utf8;
 use feature qw( say );
 
-our $VERSION = '0.000041';
+our $VERSION = '0.000042';
 
 use App::perlimports           ();
 use App::perlimports::Config   ();
@@ -262,7 +262,7 @@ sub _build_config_file {
 
     my $xdg_config = File::XDG->new( name => 'perlimports', api => 1 );
     my $file       = $xdg_config->config_home->child( $filenames[0] );
-    return -e $file ? $file : q{};
+    return -e $file ? "$file" : q{};
 }
 
 sub _read_config_file {
@@ -441,7 +441,7 @@ App::perlimports::CLI - CLI arg parsing for C<perlimports>
 
 =head1 VERSION
 
-version 0.000041
+version 0.000042
 
 =head1 DESCRIPTION
 
